# QuickNotes Application Specifications

This document provides an overview of the QuickNotes application specifications. QuickNotes is a personal knowledge management system that allows users to create and manage notes, read later items, RSS/Atom feeds, uploadable PDF documents, and perform unified full-text search across all content.

## Overview

QuickNotes is built with a Go backend and a Svelte frontend. It uses SQLite for data storage and provides a RESTful API for communication between the frontend and backend. In addition, the application includes an Emacs mode for integrated access directly from the Emacs editor.

## Specification Documents

The following table lists all the specification documents for the QuickNotes application:

| Domain           | Description                                                 | Link                                     |
|------------------|-------------------------------------------------------------|------------------------------------------|
| Architecture     | Overall system architecture                                 | [Architecture](specs/architecture.md)    |
| Notes            | Note creation, management, and linking                      | [Notes](specs/notes.md)                    |
| Readlist         | Save articles for later with automatic content extraction   | [Readlist](specs/readlist.md)              |
| Feeds            | RSS/Atom feed subscriptions and entries                     | [Feeds](specs/feeds.md)                    |
| Documents        | Upload and view PDF documents                               | [Documents](specs/documents.md)            |
| Omnisearch       | Full-text search across all domains                         | [Omnisearch](specs/omnisearch.md)          |
| Database         | Database schema and relationships                           | [Database](specs/database.md)              |
| API              | API endpoints and communication                             | [API](specs/api.md)                        |
| Frontend         | User interface and client-side features                     | [Frontend](specs/frontend.md)              |
| Authentication   | Local-only authentication and potential future enhancements | [Authentication](specs/authentication.md)  |
| Code Quality     | Refactoring plan to meet new code quality standards         | [Code Quality Refactoring](specs/code_quality_refactoring.md) |

## Key Features

- Create, edit, and delete notes with Markdown support
- Link notes together using wiki-style syntax
- Visualize note connections with an interactive graph
- Save articles for later reading with automatic content extraction
- Manage and read RSS/Atom feeds
- Upload and view PDF documents directly in the app
- Unified full-text search (Omnisearch) across all content
- Emacs integration for seamless workflow

## Technology Stack

- **Backend**: Go with Gin web framework and GORM; SQLite for storage
- **Frontend**: Svelte with SvelteKit, Bulma CSS, FontAwesome
- **Search Engine**: Bleve for full-text search
- **PDF Viewing**: PDF.js-like viewer integrated in the frontend

## Development and Deployment

- Designed for local use with potential for scalability
- Documents can be stored on local disk or blob storage (S3) in future
- Comprehensive API and Emacs mode for enhanced user interaction
- Code quality standards enforced through linting, testing, and code reviews 